@@ -1,9 +1,12 @@
+import json
 import re
 from datetime import datetime
 from decimal import Decimal
 from typing import TYPE_CHECKING, Any, List, Optional, Union
 from urllib.parse import urlencode
 
+from zeep.helpers import serialize_object
+
 from .enums import PaymentMethod, SequenceScope
 from .item import Fee, TaxItem
 from .oib import OIB
@@ -216,6 +219,11 @@ class BaseDocument:
             self.client.signer,
         )
 
+    def to_dict(self) -> dict:
+        """Serialize a document to JSON"""
+        raw = serialize_object(self.to_ws_object())
+        return json.loads(json.dumps(raw, default=str))
+
 
 class Invoice(BaseDocument):
     """
@@ -510,14 +518,23 @@ class Invoice(BaseDocument):
             SpecNamj=None,
         )
 
-    def get_qr_link(self, jir=None):
+    def get_qr_link(self, jir: Optional[str] = None):
+        """
+        Get a fiskal verification link for encoding as QR
+
+        Args:
+            jir: Invoice JIR (optional - if not set, ZKI is used instead)
+
+        Returns:
+            link to the Fiskalizacija verification service
+        """
 
         # Calculate ZKI even if JIR is specified so it validates other
         # required elements
         zki = self.calculate_zki()
 
         params = {
-            "izn": str(int(123 * self.total)),
+            "izn": str(int(100 * self.total)),
             "datv": self.issued_at.strftime("%Y%m%d_%H%M"),
         }
 
